if [ ! -e /etc/irssi.conf ]
then
    /usr/bin/mkdir -p /etc
    /usr/bin/cp /etc/defaults/etc/irssi.conf /etc/irssi.conf
fi

